#pragma once
#ifndef __FAR2SDK_FARCOMMON_H__
#define __FAR2SDK_FARCOMMON_H__

typedef int FarLangMsgID;
typedef uint32_t FarKey;

#ifndef FARLANGMSGID_BAD
# define FARLANGMSGID_BAD ((FarLangMsgID)-1)
#endif

#ifndef CP_AUTODETECT
# define CP_AUTODETECT ((UINT)-1)
#endif

#endif // __FAR2SDK_FARCOMMON_H__
